<?php

/**
 * Action Profile 
 * 
 * This is my profile action
 * 
 * @link http://getfrapi.com
 * @author Frapi <frapi@getfrapi.com>
 * @link /profile
 */
class Action_Profile extends Frapi_Action implements Frapi_Action_Interface
{

    /**
     * Required parameters
     * 
     * @var An array of required parameters.
     */
    protected $requiredParams = array();

    /**
     * The data container to use in toArray()
     * 
     * @var A container of data to fill and return in toArray()
     */
    private $data = array();

    /**
     * Data dir
     *
     * @var A data directory.
     */
    protected $dataDir = '';
    
    /** 
     * constructor
     *
     * initalize needed properties.
     */
    public function __construct()
    {
        /*
         * Initalize needed variables
         */
        $this->dataDir    = 'D:/blueParabola/Projects/APIClass/data/';
        return;
        
    }
    
    /**
     * To Array
     * 
     * This method returns the value found in the database 
     * into an associative array.
     * 
     * @return array
     */
    public function toArray()
    {
        return $this->data;
    }

    /**
     * Default Call Method
     * 
     * This method is called when no specific request handler has been found
     * 
     * @return array
     */
    public function executeAction()
    {
        return $this->toArray();
    }

    /**
     * Get Request Handler
     * 
     * This method is called when a request is a GET
     * 
     * @return array
     */
    public function executeGet()
    {
        $userid = $this->getParam('userid', self::TYPE_INT);
        $fileName = $this->dataDir.$userid.'.user';

        if ($userid>0 && file_exists($fileName)) {
            $this->data = unserialize(file_get_contents($fileName));
    
            return $this->toArray();
        } else {
            throw new Frapi_Error('USER_DOES_NOT_EXIST');
        }
        
        return;
    }

    /**
     * Post Request Handler
     * 
     * This method is called when a request is a POST
     * 
     * @return array
     */
    public function executePost()
    {
        $userid = $this->getParam('userid', self::TYPE_INT);
        $fileName = $this->dataDir.$userid.'.user';

        $firstName = filter_var($this->getParam('firstName', self::TYPE_STRING),FILTER_SANITIZE_STRING);
        $lastName = filter_var($this->getParam('lastName', self::TYPE_STRING),FILTER_SANITIZE_STRING);
        
        if ($userid>0 && !file_exists($fileName)) {
                $user = array(
                    'firstName' => $firstName,
                    'lastName'  => $lastName,
                );
                $output = serialize($user);
                file_put_contents($fileName,$output);

    
            return $this->toArray();
        } else {
            throw new Frapi_Error('USER_ALREADY_EXISTS');
        }
        
        return;
    }

    /**
     * Put Request Handler
     * 
     * This method is called when a request is a PUT
     * 
     * @return array
     */
    public function executePut()
    {
        $userid = $this->getParam('userid', self::TYPE_INT);
        $fileName = $this->dataDir.$userid.'.user';

        $firstName = filter_var($this->getParam('firstName', self::TYPE_STRING),FILTER_SANITIZE_STRING);
        $lastName  = filter_var($this->getParam('lastName', self::TYPE_STRING),FILTER_SANITIZE_STRING);
        
        if ($userid>0 && file_exists($fileName)) {
                $user = array(
                    'firstName' => $firstName,
                    'lastName'  => $lastName,
                );
                $output = serialize($user);
                file_put_contents($fileName,$output);
    
            return new Frapi_Response(array('code'=>202, 'data'=>$this->data));
        } else {
            throw new Frapi_Error('USER_DOES_NOT_EXISTS');
        }
        
        return;
    }

    /**
     * Delete Request Handler
     * 
     * This method is called when a request is a DELETE
     * 
     * @return array
     */
    public function executeDelete()
    {
        $userid = $this->getParam('userid', self::TYPE_INT);
        $fileName = $this->dataDir.$userid.'.user';

        if (!file_exists($fileName)) {
            throw new Frapi_Error('USER_DOES_NOT_EXISTS');
        } else {
            unlink($fileName);
        }        
        return $this->toArray();
    }

    /**
     * Head Request Handler
     * 
     * This method is called when a request is a HEAD
     * 
     * @return array
     */
    public function executeHead()
    {
        return $this->toArray();
    }


}