<?php

class ProfileController extends Zend_Controller_Action
{
    /**
     * @var string directory where data files are stored.
     */
    protected $_dataDir = '';
    
    /*
     * Setup, grab the options, define the data directory, etc.
     */
    public function init()
    {
        /*
         * Turn off autorendering
         */
        $this->_helper->viewRenderer->setNoRender();
        
        /*
         * Initalize our data directory
         */
        $this->_dataDir    = 'D:/blueParabola/Projects/APIClass/data/';
        
        /*
         * Code blatently stolen from Lorna Jane Mitchell
         * http://www.lornajane.net/posts/2009/Adding-PUT-variables-to-Request-Object-in-Zend-Framework
         *
         * With no small amout of help from the Supreme Allied Commander himself
         * http://weierophinney.net/matthew/archives/233-Responding-to-Different-Content-Types-in-RESTful-ZF-Apps.html
         */
        if($this->getRequest()->isPut()) {
            parse_str($this->getRequest()->getRawBody(), $params);
            foreach($params as $key => $value) {
                $this->getRequest()->setParam($key, $value);
            }
        }
    }


    /*
     * Not used in this controller
     */
    public function indexAction()
    {
        /*
         * If we cared, we could put an error message here telling the user
         * that they do not have access or they have made a wrong call.
         */
        $this->_helper->viewRenderer->setNoRender(false);
    }

    
    /*
     * Process a GET request
     */
    public function processGet()
    {
        /*
         * Filter Input
         */
        $filter = new Zend_Filter_Int();
        $userid = $filter->filter($this->getRequest()->getParam('userid'));

        /*
         * Create the file name
         */
        $fileName = $this->_dataDir.$userid.'.user';
    
        if ($userid>0) {
            if (file_exists($fileName)) {
                $returnValue = unserialize(file_get_contents($fileName));
                $this->_helper->json($returnValue);
            } else {
                $this->getResponse()->setHttpResponseCode(404);
            }
        }
    }

    /*
     * Process a POST request
     */
    public function processPost()
    {
        /*
         * Filter Input
         */
        $filter = new Zend_Filter();
        $filter->addFilter(new Zend_Filter_Alpha())
               ->addFilter(new Zend_Filter_StringTrim());
        
        $firstName = $filter->filter($this->getRequest()->getParam('firstName'));
        $lastName  = $filter->filter($this->getRequest()->getParam('lastName'));
        
        /*
         * Filter Input
         */
        $filter = new Zend_Filter_Int();
        $userid = $filter->filter($this->getRequest()->getParam('userid'));

        /*
         * Create the file name
         */
        $fileName = $this->_dataDir.$userid.'.user';

        if (file_exists($fileName)) {
            $this->getResponse()->setHttpResponseCode(409);
        } else {
            $user = array(
                'firstName' => $firstName,
                'lastName'  => $lastName,
            );
            $output = serialize($user);
            file_put_contents($fileName,$output);
            $this->getResponse()->setHttpResponseCode(201);
        }        
    }


    /*
     * Process a PUT request
     */
    public function processPut()
    {
        /*
         * Filter Input
         */
        $filter = new Zend_Filter();
        $filter->addFilter(new Zend_Filter_Alpha())
               ->addFilter(new Zend_Filter_StringTrim());
        
        $firstName = $filter->filter($this->getRequest()->getParam('firstName'));
        $lastName  = $filter->filter($this->getRequest()->getParam('lastName'));
        
        /*
         * Filter Input
         */
        $filter = new Zend_Filter_Int();
        $userid = $filter->filter($this->getRequest()->getParam('userid'));

        /*
         * Create the file name
         */
        $fileName = $this->_dataDir.$userid.'.user';

        if (!file_exists($fileName)) {
            $this->getResponse()->setHttpResponseCode(404);
        } else {
            $user = array(
                'firstName' => $firstName,
                'lastName'  => $lastName,
            );
            $output = serialize($user);
            file_put_contents($fileName,$output);
            $this->getResponse()->setHttpResponseCode(202);
        }
    }
    

    /*
     * Process a DELETE request
     */
    public function processDelete()
    {
        
        /*
         * Filter Input
         */
        $filter = new Zend_Filter_Int();
        $userid = $filter->filter($this->getRequest()->getParam('userid'));

        /*
         * Create the file name
         */
        $fileName = $this->_dataDir.$userid.'.user';

        if (!file_exists($fileName)) {
            $this->getResponse()->setHttpResponseCode(404);
        } else {
            unlink($fileName);
            $this->getResponse()->setHttpResponseCode(200);
        }            
    }
    
    
    /*
     * Determine which verb to process and call the appropriate action.
     */
    public function __call($method,$args)
    {
        /*
         * We don't use the action as an action but we do use it as a parameter, the userid
         */
        $this->getRequest()->setParam('userid',$this->getRequest()->getParam('action'));

        /*
         * Ok, now figure out what we are supposed to do and do it.
         */
          if ($this->getRequest()->isGet()) {
            $actionName = "processGet";
        } else if ($this->getRequest()->isPost()) {
            $actionName = "processPost";
        } else if ($this->getRequest()->isPut()) {
            $actionName = "processPut";
        } else if ($this->getRequest()->isDelete()) {
            $actionName = "processDelete";
        } else {
            throw new Zend_Exception('Cannot process request');
        }

        $this->$actionName();
        
        return;
    }
/*
    public function routeAction()   
    {
        $this->_forward(strtolower($this->getRequest()->getMethod()));
    }
*/
}

