<?php
/*
 * handCode.php
 * Cal Evans <cal@calevans.com>
 *
 * This is an example script of how a quick and dirty API could be put together.
 * Only profile is fleshed out. It demonstrates how to differentiate betweent
 * the method types and how to return payloads and status codes.
 *
 * It ignores most secutiy and authorization.
 */

/*
 * Initalize needed variables
 */
$dataDir    = dirname(__FILE__).'/../data/';


/*
 * Get and filter the parameters passed in.
 * Sample URL
 * /profile/1
 */
$params = explode('/',substr($_SERVER['REQUEST_URI'],1));

$action     = filter_var($params[0],FILTER_SANITIZE_STRING);
$userid     = filter_var($params[1],FILTER_SANITIZE_NUMBER_INT);
$method     = filter_var($_SERVER['REQUEST_METHOD'],FILTER_SANITIZE_STRING);
$statusCode = "200 WTF";
$location   = '';

/*
 * The Big Switch
 * Each action has a case. inside that case, the methods are handled.
 */
switch ($action)
{
    case 'profile':
        /*
         * Most profile actions will require access to the file. so we define
         * the file name early on.
         */
        $fileName = $dataDir.$userid.'.user';

        /*
         * GET a profile
         */
        if ($method==='GET') {

            if ($userid>0) {
                if (file_exists($fileName)) {
                    $returnValue = json_encode(unserialize(file_get_contents($fileName)));
                    $statusCode = '200 User Found';
                    break;
                } else {
                    $statusCode = '404 User Not Found';
                    break;
                }
            } else {
                    $statusCode = '404 User Not Found';
                    break;                
            }
            
        /*
         * POST a profile
         */
        } else if ($method==='POST') {
            $firstName = filter_var($_POST['firstName'],FILTER_SANITIZE_STRING);
            $lastName  = filter_var($_POST['lastName'],FILTER_SANITIZE_STRING);
            if (file_exists($fileName)) {
                $statusCode = '409 User already exists';
                break;
            } else {
                $user = array(
                    'firstName' => $firstName,
                    'lastName'  => $lastName,
                );
                $output = serialize($user);
                file_put_contents($fileName,$output);
                $statusCode = '201 User Created';
                $returnValue = json_encode(array('message'=>$userid.' created'));
                break;
            }
            
        /*
         * PUT a profile
         */
        } else if ($method==='PUT') {
            parse_str(file_get_contents('php://input'), $put_vars);
            $firstName = filter_var($put_vars['firstName'],FILTER_SANITIZE_STRING);
            $lastName  = filter_var($put_vars['lastName'],FILTER_SANITIZE_STRING);

            if (!file_exists($fileName)) {
                $statusCode = '404 User does not exists';
                break;
            } else {
                $user = array(
                    'firstName' => $firstName,
                    'lastName'  => $lastName,
                );
                $output = serialize($user);
                file_put_contents($fileName,$output);
                $statusCode = '202 User updated';                
                break;
            }
            
        /*
         * Delete a profile
         */
        } else if ($method==='DELETE') {
            if (!file_exists($fileName)) {
                $statusCode = '404 User does not exists';
                break;
            } else {
                unlink($fileName);
                $statusCode = '200 User deleted';
                break;
            }            
        } else {
            // deal with an error since we only allow GET, PUT and POST
        }
        
    case 'friends':
        // stubbed out. if we wanted, we could do more here.        
    case 'status':
        // stubbed out. if we wanted, we could do more here.        
        
    default:
}


/*
 * Handle the output.
 */
header("HTTP/1.0 {$statusCode}");
header('Content-type: application/json');
header('Content-length: '.strlen($returnValue));
echo $returnValue;
?>
